@@ -1,7 +1,8 @@
 #!/bin/sh
 
 #gettextize --force --copy --intl --no-changelog
+autopoint --force
 aclocal
 autoheader
-automake --add-missing --gnu
+automake --copy --add-missing --force-missing --gnu
 autoconf
