@@ -177,7 +177,7 @@ typedef struct YYLTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 181 "calleridparser.c"
+#line 181 "/home/ivan/src/ant-phone/src/calleridparser.c"
 
 #ifdef short
 # undef short
@@ -1404,7 +1404,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1408 "calleridparser.c"
+#line 1408 "/home/ivan/src/ant-phone/src/calleridparser.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
