@@ -4,6 +4,7 @@
  * This file is part of ANT (Ant is Not a Telephone)
  *
  * Copyright 2002, 2003 Roland Stigge
+ * Copyright 2007 Ivan Schreter
  *
  * ANT is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -252,34 +253,34 @@ static void controlpad_mute_cb(GtkWidget *button, gpointer data) {
  */
 static void controlpad_record_cb(GtkWidget *button, gpointer data) {
   session_t *session = (session_t *) data;
-  char *digits = NULL;
 
-  if (button == session->record_checkbutton) {
+  if (button == session->call_record_checkbutton) {
+    /* forward toggle to primary checkbox */
+    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button))) { /* record! */
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
+                                   session->record_checkbutton), TRUE);
+    } else {
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
+                                   session->record_checkbutton), FALSE);
+    }
+  } else if (button == session->record_checkbutton) {
     if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button))) { /* record! */
       session->option_record = 1;
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
+                                   session->call_record_checkbutton), TRUE);
+
       if (session->state == STATE_CONVERSATION) {
-	if (recording_open(session->recorder,
-	      		   digits = util_digitstime(&session->vcon_time),
-			   session->option_recording_format))
-	{
-          fprintf(stderr, "Error opening audio file.\n");
-	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
-				       session->record_checkbutton), FALSE);
-	  return;
-	}
-        free(digits);
-	cid_row_mark_record(session, session->cid_num - 1);
+        if (session_start_recording(session) == 0) {
+          cid_row_mark_record(session, session->cid_num - 1);
+        }
       }
     } else { /* don't record! */
       session->option_record = 0;
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
+                                   session->call_record_checkbutton), FALSE);
+
       if (session->state == STATE_CONVERSATION) {
-	recording_write(session->recorder, session->rec_buf_local,
-	                session->rec_buf_local_index, RECORDING_LOCAL);
-	recording_write(session->recorder, session->rec_buf_remote,
-	                session->rec_buf_remote_index, RECORDING_REMOTE);
         recording_close(session->recorder);
-        session->rec_buf_local_index = 0;
-        session->rec_buf_remote_index = 0;
       }
     }
     gtk_widget_set_sensitive(session->record_checkbutton_local,
@@ -441,6 +442,15 @@ GtkWidget *controlpad_new(session_t *session) {
 		     GTK_SIGNAL_FUNC(controlpad_record_cb), session);
   session->record_checkbutton = record_checkbutton;
 
+  session->call_record_checkbutton =
+      gtk_check_button_new_with_label(_("Record to file"));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(session->call_record_checkbutton),
+                               session->option_record);
+  gtk_widget_show(session->call_record_checkbutton);
+  gtk_signal_connect(GTK_OBJECT(session->call_record_checkbutton), "toggled",
+                     GTK_SIGNAL_FUNC(controlpad_record_cb), session);
+  gtk_container_add(GTK_CONTAINER(session->call_topbox), session->call_record_checkbutton);
+
   record_checkbutton_local =
     gtk_check_button_new_with_label(_("Record local channel"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(record_checkbutton_local),
