@@ -159,7 +159,7 @@ typedef union YYSTYPE
   isdn_tree_node_t* element;
 }
 /* Line 187 of yacc.c.  */
-#line 163 "isdnparser.c"
+#line 163 "/home/ivan/src/ant-phone/src/isdnparser.c"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -184,7 +184,7 @@ typedef struct YYLTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 188 "isdnparser.c"
+#line 188 "/home/ivan/src/ant-phone/src/isdnparser.c"
 
 #ifdef short
 # undef short
@@ -1514,7 +1514,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1518 "isdnparser.c"
+#line 1518 "/home/ivan/src/ant-phone/src/isdnparser.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
