@@ -1,5 +1,5 @@
 /*
- * OSS sound handling functions
+ * ALSA sound handling functions
  *
  * This file is part of ANT (Ant is Not a Telephone)
  *
@@ -41,6 +41,7 @@
   #include <stdlib.h>
 #endif
 #include <string.h>
+#include <ctype.h>
 
 /* own header files */
 #include "globals.h"
@@ -60,6 +61,76 @@ int default_audio_priorities[] = {SND_PCM_FORMAT_S16_LE,
 
 /*--------------------------------------------------------------------------*/
 
+int audio_enum_devices(audio_enum_fnc_t callback,
+                       audio_direction_t dir,
+                       void *context)
+{
+  static void **hints = 0;
+  void **n;
+  char *name, *descr, *io, *d, *p, *r;
+  const char *filter;
+  int err;
+  int wasspace;
+
+  if (hints == 0)
+  {
+    err = snd_device_name_hint(-1, "pcm", &hints);
+    if (err < 0)
+    {
+      errprintf("AUDIO: snd_device_name_hint for pcm failed: %s\n",
+              snd_strerror(err));
+      return err;
+    }
+  }
+
+  n = hints;
+  filter = (dir == AUDIO_DIR_CAPTURE) ? "Input" : "Output";
+  while (*n != NULL) {
+    name = snd_device_name_get_hint(*n, "NAME");
+    descr = snd_device_name_get_hint(*n, "DESC");
+    io = snd_device_name_get_hint(*n, "IOID");
+
+    if (io == NULL || strcmp(io, filter) == 0)
+    {
+      // have a device
+      dbgprintf(2, "AUDIO: have device (%s): %s\n", io, name);
+
+      p = r = d = strdup(descr);
+      wasspace = 0;
+
+      while (*p)
+      {
+        if (!isspace(*p)) {
+          if (wasspace)
+            *d++ = ' ';
+          *d++ = *p++;
+          wasspace = 0;
+        } else {
+          wasspace = 1;
+          p++;
+        }
+      }
+      *d = 0;
+
+      callback(context, name, r);
+      free(r);
+    }
+
+    if (name != NULL)
+      free(name);
+    if (descr != NULL)
+      free(descr);
+    if (io != NULL)
+      free(io);
+
+    n++;
+  }
+
+  return 0;
+}
+
+/*--------------------------------------------------------------------------*/
+
 /*!
  * @brief Common initialization for a specific audio device
  *
@@ -115,7 +186,8 @@ static int init_audio_device(snd_pcm_t *audio,
   if (rspeed != *speed) {
     errprintf("AUDIO: Audio speed doesn't match (requested %dHz, got %dHz)\n",
               *speed, rspeed);
-    return -EINVAL;
+    *speed = rspeed;
+    /*return -EINVAL;*/
   }
 
   buffer_time = 150000;
@@ -177,6 +249,17 @@ static int init_audio_device(snd_pcm_t *audio,
     return err;
   }
 
+  if ((err = snd_pcm_sw_params(audio, swparams)) < 0) {
+    printf("Unable to set sw params for audio (required): %s\n", snd_strerror(err));
+    return err;
+  }
+
+  if ((err = snd_pcm_sw_params_current(audio, swparams)) < 0) {
+    errprintf("AUDIO: Unable to determine current swparams for audio: %s\n",
+              snd_strerror(err));
+    return err;
+  }
+
   if ((err = snd_pcm_sw_params_set_silence_size(audio, swparams, period_size * 2)) < 0) {
     errprintf("AUDIO: Unable to set silence threshold: %s\n",
               snd_strerror(err));
@@ -191,12 +274,9 @@ static int init_audio_device(snd_pcm_t *audio,
   }
   */
 
-  //snd_pcm_sw_params_set_avail_min(Handle,swparams,Frames);
-
-
   if ((err = snd_pcm_sw_params(audio, swparams)) < 0) {
-    printf("Unable to set sw params for audio: %s\n", snd_strerror(err));
-    return err;
+    printf("Unable to set sw params for audio (optional): %s\n", snd_strerror(err));
+    /*return err;*/
   }
 
 #if 0
@@ -245,7 +325,7 @@ int open_audio_devices(char *in_audio_device_name,
 
   /* set format and sampling rate */
   for (initresult = -1, priority = format_priorities;
-       initresult && priority; priority++) {
+       initresult && *priority; priority++) {
 
     *format_in = *priority;
     initresult = init_audio_device(*audio_in, *format_in, channels, speed_in, fragment_size_in);
